@@ -195,6 +195,17 @@ typedef struct text_fuzzy {
 
     candidate_t first;
     candidate_t * last;
+
+    /* When scanning an array, put the index of the element of the
+       array into "text_fuzzy->offset". The offset of the nearest
+       elements are preserved in the "candidate_t" linked list which
+       starts off with "text_fuzzy". 
+
+       There is currently no sanity check, so if the user forgets to
+       set "offset" each time around the loop, the code will not
+       notice anything amiss and just send a list of zeros back to the
+       user. */
+
     int offset;
 
     /* Does the user want to use an alphabet filter? Default is yes,
@@ -229,24 +240,49 @@ typedef struct text_fuzzy {
     unsigned int wantarray : 1;
 }
 text_fuzzy_t;
-#line 175 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+
+/* The string is not unicode so its length in unicode characters is
+   unknown. */
+
+#define TEXT_FUZZY_INVALID_UNICODE_LENGTH -1
+#line 191 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_generate_ualphabet (text_fuzzy_t * tf);
-#line 360 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+#line 376 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_compare_single (text_fuzzy_t * tf);
-#line 537 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+#line 553 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_get_candidates (text_fuzzy_t * text_fuzzy, int * n_candidates_ptr, int ** candidates_ptr);
-#line 594 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+#line 610 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_free_candidates (text_fuzzy_t * text_fuzzy, int * candidates);
-#line 611 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+#line 627 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_generate_alphabet (text_fuzzy_t * text_fuzzy);
-#line 649 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+#line 665 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_begin_scanning (text_fuzzy_t * text_fuzzy);
-#line 674 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+#line 696 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_end_scanning (text_fuzzy_t * text_fuzzy);
-#line 768 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+#line 790 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_scan_file (text_fuzzy_t * text_fuzzy, char * file_name, char ** nearest_ptr);
-#line 814 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+#line 836 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_alphabet_rejections (text_fuzzy_t * text_fuzzy, int * r);
-#line 827 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+#line 849 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
 text_fuzzy_status_t text_fuzzy_free_memory (text_fuzzy_t * text_fuzzy);
+#line 855 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_set_max_distance (text_fuzzy_t * text_fuzzy, int max_distance);
+#line 861 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_get_max_distance (text_fuzzy_t * text_fuzzy, int * max_distance);
+#line 867 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_set_transpositions (text_fuzzy_t * text_fuzzy, int transpositions);
+#line 873 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_get_transpositions (text_fuzzy_t * text_fuzzy, int * transpositions);
+#line 879 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_last_distance (text_fuzzy_t * text_fuzzy, int * last_distance);
+#line 889 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_no_alphabet (text_fuzzy_t * text_fuzzy, int yes_no);
+#line 895 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_ualphabet_rejections (text_fuzzy_t * text_fuzzy, int * ualphabet_rejections);
+#line 901 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_set_no_exact (text_fuzzy_t * text_fuzzy, int yes_no);
+#line 907 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_get_length_rejections (text_fuzzy_t * text_fuzzy, int * length_rejections);
+#line 918 "/usr/home/ben/projects/Text-Fuzzy/text-fuzzy.c.in"
+text_fuzzy_status_t text_fuzzy_get_unicode_length (text_fuzzy_t * text_fuzzy, int * unicode_length);
 #endif /* TEXT_FUZZY_H */
